@@ -2,20 +2,20 @@
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
 
-from collections import Iterable
+from collections.abc import Iterable
 
 from pinecone import Config
 from pinecone.core.client import ApiClient, Configuration
 from pinecone.core.utils.sentry import sentry_decorator as sentry
 from .core.client.models import FetchResponse, ProtobufAny, QueryRequest, QueryResponse, QueryVector, RpcStatus, \
-    ScoredVector, SingleQueryResults, DescribeIndexStatsResponse, UpsertRequest, Vector
-from .core.utils.constants import CLIENT_VERSION_HEADER, CLIENT_ID
+    ScoredVector, SingleQueryResults, DescribeIndexStatsResponse, UpsertRequest, UpsertResponse, Vector
 from pinecone.core.client.api.vector_operations_api import VectorOperationsApi
-from pinecone.core.utils import fix_tuple_length
+from pinecone.core.utils import fix_tuple_length, get_user_agent
+import copy
 
 __all__ = [
     "Index", "FetchResponse", "ProtobufAny", "QueryRequest", "QueryResponse", "QueryVector", "RpcStatus",
-    "ScoredVector", "SingleQueryResults", "DescribeIndexStatsResponse", "UpsertRequest", "Vector"
+    "ScoredVector", "SingleQueryResults", "DescribeIndexStatsResponse", "UpsertRequest", "UpsertResponse", "Vector"
 ]
 
 from .core.utils.error_handling import validate_and_convert_errors
@@ -29,7 +29,7 @@ _OPENAPI_ENDPOINT_PARAMS = (
 class Index(ApiClient):
 
     def __init__(self, index_name: str, pool_threads=1):
-        openapi_client_config = Config.OPENAPI_CONFIG
+        openapi_client_config = copy.deepcopy(Config.OPENAPI_CONFIG)
         openapi_client_config.api_key = openapi_client_config.api_key or {}
         openapi_client_config.api_key['ApiKeyAuth'] = openapi_client_config.api_key.get('ApiKeyAuth', Config.API_KEY)
         openapi_client_config.server_variables = openapi_client_config.server_variables or {}
@@ -42,23 +42,26 @@ class Index(ApiClient):
             **openapi_client_config.server_variables
         }
         super().__init__(configuration=openapi_client_config, pool_threads=pool_threads)
-        self.set_default_header(CLIENT_VERSION_HEADER, CLIENT_ID)
+        self.user_agent = get_user_agent()
         self._vector_api = VectorOperationsApi(self)
 
     @sentry
     @validate_and_convert_errors
     def upsert(self, vectors, **kwargs):
+        _check_type = kwargs.pop('_check_type', False)
+
         def _vector_transform(item):
             if isinstance(item, Vector):
                 return item
             if isinstance(item, tuple):
                 id, values, metadata = fix_tuple_length(item, 3)
-                return Vector(id=id, values=values, metadata=metadata or {})
+                return Vector(id=id, values=values, metadata=metadata or {}, _check_type=_check_type)
             raise ValueError(f"Invalid vector value passed: cannot interpret type {type(item)}")
 
         return self._vector_api.upsert(
             UpsertRequest(
                 vectors=list(map(_vector_transform, vectors)),
+                _check_type=_check_type,
                 **{k: v for k, v in kwargs.items() if k not in _OPENAPI_ENDPOINT_PARAMS}
             ),
             **{k: v for k, v in kwargs.items() if k in _OPENAPI_ENDPOINT_PARAMS}
@@ -77,19 +80,22 @@ class Index(ApiClient):
     @sentry
     @validate_and_convert_errors
     def query(self, queries, **kwargs):
+        _check_type = kwargs.pop('_check_type', False)
+
         def _query_transform(item):
             if isinstance(item, QueryVector):
                 return item
             if isinstance(item, tuple):
                 values, filter = fix_tuple_length(item, 2)
-                return QueryVector(values=values, filter=filter)
+                return QueryVector(values=values, filter=filter, _check_type=_check_type)
             if isinstance(item, Iterable):
-                return QueryVector(values=item)
+                return QueryVector(values=item, _check_type=_check_type)
             raise ValueError(f"Invalid query vector value passed: cannot interpret type {type(item)}")
 
         return self._vector_api.query(
             QueryRequest(
                 queries=list(map(_query_transform, queries)),
+                _check_type=_check_type,
                 **{k: v for k, v in kwargs.items() if k not in _OPENAPI_ENDPOINT_PARAMS}
             ),
             **{k: v for k, v in kwargs.items() if k in _OPENAPI_ENDPOINT_PARAMS}
